pub struct ImplicitlyTaggedFmt<F>(pub Tag, pub F);Expand description
Const-constructible ASN.1 IMPLICIT tagging wrapper.
Tuple Fields
0: Tag1: FTrait Implementations
Sourceimpl<F, T> ByteLen<T> for ImplicitlyTaggedFmt<F>
impl<F, T> ByteLen<T> for ImplicitlyTaggedFmt<F>
Sourceimpl<F: Clone> Clone for ImplicitlyTaggedFmt<F>
impl<F: Clone> Clone for ImplicitlyTaggedFmt<F>
Sourceimpl<F> Consistency for ImplicitlyTaggedFmt<F>where
F: Retaggable + Consistency,
impl<F> Consistency for ImplicitlyTaggedFmt<F>where
F: Retaggable + Consistency,
Sourceopen spec fn consistent(&self, value: Self::Val) -> bool
open spec fn consistent(&self, value: Self::Val) -> bool
{ self.1.spec_retagged(self.0).consistent(value) }Sourcetype Val = <F as Consistency>::Val
type Val = <F as Consistency>::Val
The type of values whose consistency is being checked.
Sourceimpl<F, T> DerOrd<T> for ImplicitlyTaggedFmt<F>
impl<F, T> DerOrd<T> for ImplicitlyTaggedFmt<F>
Sourceproof fn lemma_der_serialize_len(&self, value: T::V)
proof fn lemma_der_serialize_len(&self, value: T::V)
Sourceopen spec fn der_remaining(&self, value: T::V, state: <F as DerState>::State) -> Seq<u8>
open spec fn der_remaining(&self, value: T::V, state: <F as DerState>::State) -> Seq<u8>
{ self.1.spec_retagged(self.0).der_remaining(value, state) }Sourceimpl<F> DerState for ImplicitlyTaggedFmt<F>where
F: Retaggable + DerState,
impl<F> DerState for ImplicitlyTaggedFmt<F>where
F: Retaggable + DerState,
Sourceimpl<F> EquivSerializers for ImplicitlyTaggedFmt<F>where
F: Retaggable + EquivSerializers,
impl<F> EquivSerializers for ImplicitlyTaggedFmt<F>where
F: Retaggable + EquivSerializers,
Sourceimpl<F> EquivSerializersGeneral for ImplicitlyTaggedFmt<F>where
F: Retaggable + EquivSerializersGeneral,
impl<F> EquivSerializersGeneral for ImplicitlyTaggedFmt<F>where
F: Retaggable + EquivSerializersGeneral,
Sourceopen spec fn equiv_general_inv(&self) -> bool
open spec fn equiv_general_inv(&self) -> bool
{ self.1.spec_retagged(self.0).equiv_general_inv() }Sourceproof fn lemma_serialize_equiv(&self, value: Self::SVal, obuf: Seq<u8>)
proof fn lemma_serialize_equiv(&self, value: Self::SVal, obuf: Seq<u8>)
Sourceimpl<F> GoodSerializer for ImplicitlyTaggedFmt<F>where
F: Retaggable + GoodSerializer,
impl<F> GoodSerializer for ImplicitlyTaggedFmt<F>where
F: Retaggable + GoodSerializer,
Sourceopen spec fn serialize_inv(&self) -> bool
open spec fn serialize_inv(&self) -> bool
{ self.1.spec_retagged(self.0).serialize_inv() }Sourceproof fn lemma_serialize_len(&self, value: Self::SVal)
proof fn lemma_serialize_len(&self, value: Self::SVal)
Sourceimpl<Format> HasAsn1Start for ImplicitlyTaggedFmt<Format>where
Format: Retaggable + HasAsn1Start,
IMPLICIT tagging delegates parsing and its start domain to the concretely retagged format.
impl<Format> HasAsn1Start for ImplicitlyTaggedFmt<Format>where
Format: Retaggable + HasAsn1Start,
IMPLICIT tagging delegates parsing and its start domain to the concretely retagged format.
Sourceopen spec fn asn1_start(&self) -> Asn1StartDomain
open spec fn asn1_start(&self) -> Asn1StartDomain
{ self.1.spec_retagged(self.0).asn1_start() }Sourceproof fn lemma_parse_implies_asn1_start(&self, input: Seq<u8>)
proof fn lemma_parse_implies_asn1_start(&self, input: Seq<u8>)
Sourceimpl<F> NoLookAhead for ImplicitlyTaggedFmt<F>where
F: Retaggable + NoLookAhead,
impl<F> NoLookAhead for ImplicitlyTaggedFmt<F>where
F: Retaggable + NoLookAhead,
Sourceopen spec fn no_lookahead_inv(&self) -> bool
open spec fn no_lookahead_inv(&self) -> bool
{ self.1.spec_retagged(self.0).no_lookahead_inv() }Sourceproof fn lemma_no_lookahead(&self, ibuf1: Seq<u8>, ibuf2: Seq<u8>)
proof fn lemma_no_lookahead(&self, ibuf1: Seq<u8>, ibuf2: Seq<u8>)
Sourceimpl<F> NonMalleable for ImplicitlyTaggedFmt<F>where
F: Retaggable + NonMalleable,
impl<F> NonMalleable for ImplicitlyTaggedFmt<F>where
F: Retaggable + NonMalleable,
Sourceopen spec fn nonmal_inv(&self) -> bool
open spec fn nonmal_inv(&self) -> bool
{ self.1.spec_retagged(self.0).nonmal_inv() }Sourceproof fn lemma_parse_non_malleable(&self, buf1: Seq<u8>, buf2: Seq<u8>)
proof fn lemma_parse_non_malleable(&self, buf1: Seq<u8>, buf2: Seq<u8>)
Sourceimpl<F> NonTailFmt for ImplicitlyTaggedFmt<F>where
F: Retaggable + NonTailFmt,
impl<F> NonTailFmt for ImplicitlyTaggedFmt<F>where
F: Retaggable + NonTailFmt,
Sourceopen spec fn serialize_dps_inv(&self) -> bool
open spec fn serialize_dps_inv(&self) -> bool
{ self.1.spec_retagged(self.0).serialize_dps_inv() }Sourceproof fn lemma_serialize_dps_prepend(&self, value: Self::SValue, obuf: Seq<u8>)
proof fn lemma_serialize_dps_prepend(&self, value: Self::SValue, obuf: Seq<u8>)
Sourceproof fn lemma_serialize_dps_len(&self, value: Self::SValue, obuf: Seq<u8>)
proof fn lemma_serialize_dps_len(&self, value: Self::SValue, obuf: Seq<u8>)
Sourceimpl<Input, F> Parser<Input> for ImplicitlyTaggedFmt<F>
impl<Input, F> Parser<Input> for ImplicitlyTaggedFmt<F>
Sourceimpl<F, T> Prepare<T> for ImplicitlyTaggedFmt<F>
impl<F, T> Prepare<T> for ImplicitlyTaggedFmt<F>
Sourceimpl<F> Productive for ImplicitlyTaggedFmt<F>where
F: Retaggable + Productive,
impl<F> Productive for ImplicitlyTaggedFmt<F>where
F: Retaggable + Productive,
Sourceopen spec fn productive_inv(&self) -> bool
open spec fn productive_inv(&self) -> bool
{ self.1.spec_retagged(self.0).productive_inv() }Sourceproof fn lemma_productive(&self, ibuf: Seq<u8>)
proof fn lemma_productive(&self, ibuf: Seq<u8>)
Sourceimpl<F: Retaggable> Retaggable for ImplicitlyTaggedFmt<F>
Allows IMPLICIT tagging to compose/chain through an existing IMPLICIT-tag wrapper.
impl<F: Retaggable> Retaggable for ImplicitlyTaggedFmt<F>
Allows IMPLICIT tagging to compose/chain through an existing IMPLICIT-tag wrapper.
The newer tag replaces the stored outer tag and the underlying format is retained; when used,
the underlying Retaggable implementation selects the correct primitive/constructed form.
Sourceimpl<F> SPRoundTripDps for ImplicitlyTaggedFmt<F>where
F: Retaggable + SPRoundTripDps,
impl<F> SPRoundTripDps for ImplicitlyTaggedFmt<F>where
F: Retaggable + SPRoundTripDps,
Sourceopen spec fn unambiguous(&self) -> bool
open spec fn unambiguous(&self) -> bool
{ self.1.spec_retagged(self.0).unambiguous() }Sourceproof fn theorem_serialize_dps_parse_roundtrip(&self, value: Self::T, obuf: Seq<u8>)
proof fn theorem_serialize_dps_parse_roundtrip(&self, value: Self::T, obuf: Seq<u8>)
Sourceimpl<F> SafeParser for ImplicitlyTaggedFmt<F>where
F: Retaggable + SafeParser,
impl<F> SafeParser for ImplicitlyTaggedFmt<F>where
F: Retaggable + SafeParser,
Sourceimpl<Output, F, T> Serializer<Output, T> for ImplicitlyTaggedFmt<F>
impl<Output, F, T> Serializer<Output, T> for ImplicitlyTaggedFmt<F>
Sourceopen spec fn exec_inv(&self) -> bool
open spec fn exec_inv(&self) -> bool
{ <F as Serializer<Output, T>>::exec_inv(&self.1.spec_retagged(self.0)) }Sourceexec fn serialize_into(&self, value: &T, obuf: &mut Output)
exec fn serialize_into(&self, value: &T, obuf: &mut Output)
Sourceimpl<F> SoundParser for ImplicitlyTaggedFmt<F>where
F: Retaggable + SoundParser,
impl<F> SoundParser for ImplicitlyTaggedFmt<F>where
F: Retaggable + SoundParser,
Sourceimpl<F> SpecByteLen for ImplicitlyTaggedFmt<F>where
F: Retaggable + SpecByteLen,
impl<F> SpecByteLen for ImplicitlyTaggedFmt<F>where
F: Retaggable + SpecByteLen,
Sourceimpl<F> SpecParser for ImplicitlyTaggedFmt<F>where
F: Retaggable + SpecParser,
impl<F> SpecParser for ImplicitlyTaggedFmt<F>where
F: Retaggable + SpecParser,
Sourceimpl<F> SpecSerializer for ImplicitlyTaggedFmt<F>where
F: Retaggable + SpecSerializer,
impl<F> SpecSerializer for ImplicitlyTaggedFmt<F>where
F: Retaggable + SpecSerializer,
Sourceopen spec fn spec_serialize(&self, value: Self::SVal) -> Seq<u8>
open spec fn spec_serialize(&self, value: Self::SVal) -> Seq<u8>
{ self.1.spec_retagged(self.0).spec_serialize(value) }Sourcetype SVal = <F as SpecSerializer>::SVal
type SVal = <F as SpecSerializer>::SVal
The type of values to be serialized.
Sourceimpl<F> SpecSerializerDps for ImplicitlyTaggedFmt<F>where
F: Retaggable + SpecSerializerDps,
impl<F> SpecSerializerDps for ImplicitlyTaggedFmt<F>where
F: Retaggable + SpecSerializerDps,
impl<F: Copy> Copy for ImplicitlyTaggedFmt<F>